.. currentmodule:: obspy.taup
.. automodule:: obspy.taup

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~tau.TauPyModel
       ~velocity_layer.VelocityLayer
       ~helper_classes.SlownessLayer
       ~helper_classes.TimeDist
       ~helper_classes.TimeDistGeo
       ~helper_classes.CriticalDepth

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       c_wrappers
       helper_classes
       ray_paths
       seismic_phase
       slowness_layer
       slowness_model
       tau_branch
       tau_model
       taup_create
       taup_geo
       taup_path
       taup_pierce
       taup_time
       tau
       utils
       velocity_layer
       velocity_model

    .. comment to end block
